@@ -19,6 +19,7 @@
 
 #include "gpxview.h"
 #include <math.h>
+#include <string.h>
 
 static GtkWidget *cache_description(appdata_t *appdata, cache_t *cache) {
   return html_view(appdata, cache->long_description, 
@@ -41,8 +42,7 @@ static const char *cache_size_tip[] = {
 #endif
 
 static const char *cache_size_name[] = {
-  "Regular", "Small", "Micro", "Other", 
-  "Not chosen", "Large", "Virtual" 
+  "Regular", "Small", "Micro", "Other", "Not chosen", "Large", "Virtual" 
 };
 
 void bearing_fill_hbox(GtkWidget *hbox, 
@@ -51,29 +51,31 @@ void bearing_fill_hbox(GtkWidget *hbox,
 
   if(!isnan(pos.lat) && !isnan(pos.lon)) {
     gtk_box_pack_start(GTK_BOX(hbox), gtk_image_new_from_pixbuf(
-			       		icon_bearing(refpos, pos)),1,0,0);
+			       		icon_bearing(refpos, pos)),TRUE,FALSE,0);
 
     if(!isnan(refpos.lat) && !isnan(refpos.lon)) {
       gtk_box_pack_start_defaults(GTK_BOX(hbox), 
 		   GTK_LABEL_SMALL((char*)pos_get_bearing_str(refpos, pos)));
+      gtk_box_pack_start_defaults(GTK_BOX(hbox), GTK_LABEL_SMALL("  "));
       snprintf(str, sizeof(str), _("%.1f°"), 
 	       gpx_pos_get_bearing(refpos, pos));
       gtk_box_pack_start_defaults(GTK_BOX(hbox), GTK_LABEL_SMALL(str));
       gpx_pos_get_distance_str(str, sizeof(str), 
 			     refpos, pos, appdata->imperial);
+      gtk_box_pack_start_defaults(GTK_BOX(hbox), GTK_LABEL_SMALL("  "));
       gtk_box_pack_start(GTK_BOX(hbox), 
-	     gtk_label_attrib(str, SIZE_SMALL, STRIKETHROUGH_NONE),1,0,0);
+	     gtk_label_attrib(str, SIZE_SMALL, STRIKETHROUGH_NONE),TRUE,FALSE,0);
     } else
       gtk_box_pack_start(GTK_BOX(hbox), 
 			 gtk_label_attrib(_("(no position)"), 
-			 SIZE_SMALL, STRIKETHROUGH_NONE),1,0,0);
+			 SIZE_SMALL, STRIKETHROUGH_NONE),TRUE,FALSE,0);
   } else
     gtk_box_pack_start(GTK_BOX(hbox), 
 	   gtk_label_attrib(_("(invalid position in notes)"), 
-			    SIZE_SMALL, STRIKETHROUGH_NONE),1,0,0);
+			    SIZE_SMALL, STRIKETHROUGH_NONE),TRUE,FALSE,0);
 }
 
-/* this function sets everthing related to the coordinate. used to */
+/* this function sets everything related to the coordinate. used to */
 /* cope with the user setting a new "note coordinate" */
 void overview_coordinate_update(cache_context_t *context) {
   if(!context->notes.modified)
@@ -162,9 +164,15 @@ static void gcvote_callback(vote_t *vote, gpointer data) {
   context->gcvote_request = NULL;
 }
 
+static void pack_vcentered(GtkWidget *vbox, GtkWidget *child) {
+  GtkWidget *align = gtk_alignment_new(0.5, 0.5, 0.0, 0.0);
+  gtk_container_add(GTK_CONTAINER(align), child);
+  gtk_box_pack_start_defaults(GTK_BOX(vbox), align);
+}
+
 static GtkWidget *cache_overview(cache_context_t *context) {
   GtkWidget *vbox, *ivbox;
-  GtkWidget *table, *tip;
+  GtkWidget *colbox, *tip;
   char str[64];
 #ifndef USE_MAEMO
   GtkTooltips *tips = gtk_tooltips_new();
@@ -172,14 +180,23 @@ static GtkWidget *cache_overview(cache_context_t *context) {
   appdata_t *appdata = context->appdata;
   cache_t *cache = context->cache;
 
-  vbox = gtk_vbox_new(FALSE, 0);
+  vbox = gtk_vbox_new(FALSE, 4);
 
-  table =  gtk_table_new(3,4, FALSE);
+  /* hbox containing the four columns of cache details */
+  GtkWidget *ihbox = gtk_hbox_new(FALSE, 0);
+
+  /* vbox containing leftmost column (icon and container) */
+  colbox = gtk_vbox_new(FALSE, 0);
 
   if(cache->type != CACHE_TYPE_UNKNOWN) {
-    gtk_table_attach(GTK_TABLE(table), 
-	     tip = icon_get_widget(ICON_CACHE_TYPE, cache->type), 0,1,0,1,
-	     GTK_FILL, 0, GTK_FILL, 0);
+    gtk_box_pack_start_defaults(GTK_BOX(colbox), 
+
+#if defined(USE_MAEMO) && (MAEMO_VERSION_MAJOR >= 5)
+    tip = icon_get_widget(ICON_CACHE_TYPE_2X, cache->type));
+#else
+    tip = icon_get_widget(ICON_CACHE_TYPE_1_5X, cache->type));
+#endif
+
 #ifndef USE_MAEMO
     gtk_tooltips_set_tip(tips, tip, _(cache_type_tip[cache->type]), NULL);
 #endif
@@ -194,13 +211,16 @@ static GtkWidget *cache_overview(cache_context_t *context) {
     gtk_box_pack_start(GTK_BOX(ivbox), 
 		       icon_get_widget(ICON_CACHE_SIZE, cache->container),
 		       FALSE, FALSE, 0);
-    gtk_table_attach(GTK_TABLE(table), ivbox, 0,1,1,2,
-		     GTK_EXPAND | GTK_FILL, 0, GTK_FILL, 0);
+
+    pack_vcentered(colbox, ivbox);
 #ifndef USE_MAEMO
     gtk_tooltips_set_tip(tips, ivbox, _(cache_size_tip[cache->container]), NULL);
 #endif
   }
 
+  gtk_box_pack_start_defaults(GTK_BOX(ihbox), colbox);
+  colbox = gtk_vbox_new(FALSE, 0);
+
   /* ----------------------- id ---------------------------- */
   if(cache->id) {
     int strike = cache->archived?STRIKETHROUGH_RED:
@@ -208,23 +228,23 @@ static GtkWidget *cache_overview(cache_context_t *context) {
     GtkWidget *lbl = link_button_attrib(context->appdata, 
 					cache->id, context->cache->url,
 					SIZE_BIG, strike);
-    gtk_table_attach(GTK_TABLE(table), lbl, 1,2,0,1, FALSE, FALSE, 0, 0);
+    pack_vcentered(colbox, lbl);
   }
 
   /* --------------- box containing owner info ------------- */
   if(cache->owner) {
-    ivbox = gtk_vbox_new(FALSE, 0);
-    gtk_box_pack_start_defaults(GTK_BOX(ivbox), GTK_LABEL_SMALL(_("by")));
+    gtk_box_pack_start_defaults(GTK_BOX(colbox), GTK_LABEL_SMALL(_("by")));
 
     static const char *owner_type = "profile/";
-    gtk_box_pack_start_defaults(GTK_BOX(ivbox), 
+    pack_vcentered(colbox,
 		link_button_by_id(appdata, cache->owner->name, 
 				  owner_type, cache->owner->id));
-    gtk_table_attach(GTK_TABLE(table), ivbox, 1,2,1,2, FALSE,FALSE,0,0);
   }
 
+  gtk_box_pack_start_defaults(GTK_BOX(ihbox), colbox);
+
   /* ----------- vbox containing all ratings ---------- */
-  GtkWidget *ratebox = gtk_vbox_new(FALSE, 0);
+  colbox = gtk_vbox_new(FALSE, 0);
 
   /* ----------- box containing difficulty rating ---------- */
   if(cache->difficulty != 0) {
@@ -236,9 +256,7 @@ static GtkWidget *cache_overview(cache_context_t *context) {
 		  icon_get_widget(ICON_STARS, (int)(cache->difficulty*2-2)),
 		       FALSE, FALSE, 0);
 
-    GtkWidget *align = gtk_alignment_new(0.5, 0.5, 0.0, 0.0);
-    gtk_container_add(GTK_CONTAINER(align), ivbox);
-    gtk_box_pack_start_defaults(GTK_BOX(ratebox), align);
+    pack_vcentered(colbox, ivbox);
 #ifndef USE_MAEMO
     sprintf(str, _("Difficulty: %.1f"), cache->difficulty);
     gtk_tooltips_set_tip(tips, ivbox, str, NULL);
@@ -253,9 +271,7 @@ static GtkWidget *cache_overview(cache_context_t *context) {
     gtk_box_pack_start(GTK_BOX(ivbox), 
 		       icon_get_widget(ICON_STARS, (int)(cache->terrain*2-2)),
 		       FALSE, FALSE, 0);
-    GtkWidget *align = gtk_alignment_new(0.5, 0.5, 0.0, 0.0);
-    gtk_container_add(GTK_CONTAINER(align), ivbox);
-    gtk_box_pack_start_defaults(GTK_BOX(ratebox), align);
+    pack_vcentered(colbox, ivbox);
 #ifndef USE_MAEMO
     sprintf(str, _("Terrain: %.1f"), cache->terrain);
     gtk_tooltips_set_tip(tips, ivbox, str, NULL);
@@ -270,22 +286,22 @@ static GtkWidget *cache_overview(cache_context_t *context) {
       gcvote_request(appdata, gcvote_callback, cache->url, context);
 
     context->votebox = gtk_vbox_new(FALSE, 0);
-    GtkWidget *align = gtk_alignment_new(0.5, 0.5, 0.0, 0.0);
-    gtk_container_add(GTK_CONTAINER(align), context->votebox);
-    gtk_box_pack_start_defaults(GTK_BOX(ratebox), align);
+    pack_vcentered(colbox, context->votebox);
 
     /* fill with vote if present on disk (will also free vote) */
     if(vote) 
       gcvote_set(context, vote);
-
-    gtk_table_attach_defaults(GTK_TABLE(table), ratebox, 2,3,0,2);
   }
 
+  gtk_box_pack_start_defaults(GTK_BOX(ihbox), colbox);
+
   /* ----------------------------------------------------- */
 
 
   /* ----------------- the two coordinates ----------------- */
   /* ----------------- and the heading/distance ------------ */
+  colbox = gtk_vbox_new(FALSE, 0);
+
   pos_t *refpos = get_pos(appdata);
 
   ivbox = gtk_vbox_new(FALSE, 0);
@@ -293,25 +309,27 @@ static GtkWidget *cache_overview(cache_context_t *context) {
                   STRIKETHROUGH:STRIKETHROUGH_NONE;
 
   /* the original coordinate is being displayed */
-  gtk_box_pack_start_defaults(GTK_BOX(ivbox), 
-       context->pos_lat_label = pos_lat(cache->pos.lat, SIZE_BIG, strike));
-  gtk_box_pack_start_defaults(GTK_BOX(ivbox), 
-       context->pos_lon_label = pos_lon(cache->pos.lon, SIZE_BIG, strike));
+  gtk_box_pack_start(GTK_BOX(ivbox), 
+       context->pos_lat_label = pos_lat(cache->pos.lat, SIZE_BIG, strike), FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(ivbox), 
+       context->pos_lon_label = pos_lon(cache->pos.lon, SIZE_BIG, strike), FALSE, FALSE, 0);
+
+  pack_vcentered(colbox, ivbox);
 
   /* but calculations may be done with respect to the overriden one */
   if(!isnan(cache->pos.lat) && !isnan(cache->pos.lon)) {
     context->bearing_hbox = gtk_hbox_new(FALSE, 0);
     bearing_fill_hbox(context->bearing_hbox, appdata, *refpos, 
 		      gpx_cache_pos(cache));
-    gtk_box_pack_start_defaults(GTK_BOX(ivbox), context->bearing_hbox);
+    pack_vcentered(colbox, context->bearing_hbox);
   }
 
-  gtk_table_attach_defaults(GTK_TABLE(table), ivbox, 3,4,0,2);
+  gtk_box_pack_start_defaults(GTK_BOX(ihbox), colbox);
  
   /* ----------------------------------------------------- */
 
-  gtk_box_pack_start(GTK_BOX(vbox), table, 0,0,0);
-  gtk_box_pack_start(GTK_BOX(vbox), gtk_hseparator_new(),FALSE,FALSE,0);
+  gtk_box_pack_start(GTK_BOX(vbox), ihbox, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), gtk_hseparator_new(), FALSE, FALSE, 0);
 
   /* ----------------------------------------------------- */
 
@@ -433,21 +451,22 @@ static GtkWidget *cache_wpts(appdata_t *appdata, wpt_t *wpt) {
 		      pos_lon(wpt->pos.lon, SIZE_BIG, STRIKETHROUGH_NONE), 
 		      2,3, wpt_row, wpt_row+1);
 
-    ihbox = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(ihbox), gtk_image_new_from_pixbuf(
+    if(refpos && !isnan(refpos->lat) && !isnan(refpos->lon)) {
+      ihbox = gtk_hbox_new(FALSE, 0);
+      gtk_box_pack_start(GTK_BOX(ihbox), gtk_image_new_from_pixbuf(
 			   icon_bearing(*refpos, wpt->pos)),1,0,0);
-    gtk_box_pack_start_defaults(GTK_BOX(ihbox), 
-          GTK_LABEL_SMALL((char*)pos_get_bearing_str(*refpos, wpt->pos)));
-    snprintf(str, sizeof(str), _("%.1f°"), 
-	   gpx_pos_get_bearing(*refpos, wpt->pos));
-    gtk_box_pack_start_defaults(GTK_BOX(ihbox), GTK_LABEL_SMALL(str));
-    gpx_pos_get_distance_str(str, sizeof(str), 
-			     *refpos, wpt->pos, appdata->imperial);
-    gtk_box_pack_start(GTK_BOX(ihbox), GTK_LABEL_SMALL(str),1,0,0);
+      snprintf(str, sizeof(str), _("%.1f°"), 
+	       gpx_pos_get_bearing(*refpos, wpt->pos));
+      gtk_box_pack_start_defaults(GTK_BOX(ihbox), GTK_LABEL_SMALL(str));
+
+      gpx_pos_get_distance_str(str, sizeof(str), 
+			       *refpos, wpt->pos, appdata->imperial);
+      gtk_box_pack_start(GTK_BOX(ihbox), GTK_LABEL_SMALL(str),1,0,0);
+      
+      gtk_table_attach_defaults(GTK_TABLE(table), ihbox, 3,4, 
+				wpt_row+0, wpt_row+1);
+    }
 
-    gtk_table_attach_defaults(GTK_TABLE(table), ihbox, 3,4, 
-    			      wpt_row+0, wpt_row+1);
-    
     /* ------------------ description ------------------------- */
     if(wpt->desc) 
       gtk_table_attach_defaults(GTK_TABLE(table), 
@@ -508,9 +527,16 @@ static GtkWidget *cache_tbs(appdata_t *appdata, tb_t *tb) {
     static const char *tb_type = "track/details.aspx";
     
     /* --------------------- icon/ref/name -------------------------*/
-    gtk_table_attach_defaults(GTK_TABLE(table), icon_get_widget(ICON_TB, 0), 
-			      0, 1, tb_row+0, tb_row+1);
+    GtkWidget *icon = NULL;
+    if((strcasestr(tb->name, "coin") != 0) ||
+       (strcasestr(tb->name, "muenze") != 0) ||
+       (strcasestr(tb->name, "münze") != 0))
+      icon = icon_get_widget(ICON_TB, 1);   /* coin icon */
+    else
+      icon = icon_get_widget(ICON_TB, 0);   /* tb icon */
 
+    gtk_table_attach_defaults(GTK_TABLE(table), icon, 
+			      0, 1, tb_row+0, tb_row+1);
 
     if(tb->ref) {
       GtkWidget *ref = link_button_by_id(appdata, tb->ref, tb_type, tb->id);
@@ -582,7 +608,7 @@ static GtkWidget *cache_logs(appdata_t *appdata, cache_context_t *context,
     gtk_signal_connect(GTK_OBJECT(but), "clicked",
 		       GTK_SIGNAL_FUNC(on_gclink_clicked), context);
 
-    gtk_box_pack_start_defaults(GTK_BOX(vbox), but);
+    gtk_box_pack_start(GTK_BOX(vbox), but, FALSE, FALSE, 0);
   }
 #endif
 
@@ -631,9 +657,9 @@ static GtkWidget *cache_logs(appdata_t *appdata, cache_context_t *context,
 
     gtk_box_pack_start(GTK_BOX(ivbox), ihbox, FALSE, FALSE, 0);
 
-    gtk_table_attach_defaults(GTK_TABLE(table), ivbox, 0, 1,
-			      2*log_cnt, 2*log_cnt+1);
-    
+    gtk_table_attach(GTK_TABLE(table), ivbox, 0, 1,
+		     2*log_cnt, 2*log_cnt+1, 0, GTK_EXPAND | GTK_FILL, 0, 0);
+
     if(log->text) {
       gtk_table_attach_defaults(GTK_TABLE(table),
 	html_view(appdata, log->text, 
@@ -654,7 +680,7 @@ static GtkWidget *cache_logs(appdata_t *appdata, cache_context_t *context,
     log_cnt++;
   }
 
-  gtk_box_pack_start_defaults(GTK_BOX(vbox), table);
+  gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
 
 #ifndef  USE_PANNABLE_AREA
   gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scrolled_window), 
@@ -775,6 +801,7 @@ static GtkWidget *notebook_new(void) {
 #endif
 }
 
+#ifdef CUSTOM_NOTEBOOK
 static void on_notebook_button_clicked(GtkWidget *button, gpointer data) {
   GtkNotebook *nb = 
     GTK_NOTEBOOK(g_object_get_data(G_OBJECT(data), "notebook"));
@@ -782,6 +809,7 @@ static void on_notebook_button_clicked(GtkWidget *button, gpointer data) {
   gint page = (gint)g_object_get_data(G_OBJECT(button), "page");
   gtk_notebook_set_current_page(nb, page);
 }
+#endif
 
 static void notebook_append_page(GtkWidget *notebook, 
 				 GtkWidget *page, char *label) {
