@@ -20,6 +20,8 @@
 #ifndef CACHE_H
 #define CACHE_H
 
+#include "gcvote.h"
+
 /* number of heading values used max for averaging */
 #define MAX_AVERAGE 10 
 
@@ -58,6 +60,9 @@ typedef struct {
   GtkWidget *pos_lat_label, *pos_lon_label;
   GtkWidget *bearing_hbox;
 
+  GtkWidget *votes, *quality, *votebox;
+  gcvote_request_t *gcvote_request;
+
 #ifdef USE_MAEMO
   guint handler_id;
 #endif
