@@ -20,6 +20,12 @@
 #include "gpxview.h"
 #include "custom_type_renderer.h"
 
+#if defined(USE_MAEMO) && (MAEMO_VERSION_MAJOR >= 5)
+#define CUSTOM_ICON_TYPE  ICON_CACHE_TYPE_1_5X
+#else
+#define CUSTOM_ICON_TYPE  ICON_CACHE_TYPE
+#endif
+
 /* http://scentric.net/tutorial/sec-custom-cell-renderers.html */
 /* https://stage.maemo.org/svn/maemo/projects/haf/trunk/gtk+/gtk/gtkcellrendererpixbuf.c */
 /* https://stage.maemo.org/svn/maemo/projects/haf/trunk/gtk+/gtk/gtkcellrenderertext.c */
@@ -225,7 +231,7 @@ custom_cell_renderer_type_get_size (GtkCellRenderer *cell,
    GtkWidget *widget, GdkRectangle *cell_area, gint *x_offset, 
    gint *y_offset, gint *width, gint *height) {
   CustomCellRendererType *celltype = CUSTOM_CELL_RENDERER_TYPE (cell);
-  GdkPixbuf *pixbuf = icon_get(ICON_CACHE_TYPE, celltype->type>>8);
+  GdkPixbuf *pixbuf = icon_get(CUSTOM_ICON_TYPE, celltype->type>>8);
 
   if(!pixbuf) return;
 
@@ -264,7 +270,7 @@ custom_cell_renderer_type_render (GtkCellRenderer *cell,
                                       guint            flags)
 {
   CustomCellRendererType *celltype = CUSTOM_CELL_RENDERER_TYPE (cell);
-  GdkPixbuf *pixbuf = icon_get(ICON_CACHE_TYPE, celltype->type>>8);
+  GdkPixbuf *pixbuf = icon_get(CUSTOM_ICON_TYPE, celltype->type>>8);
   GdkRectangle all_rect;
   GdkRectangle draw_rect;
 
@@ -294,11 +300,11 @@ custom_cell_renderer_type_render (GtkCellRenderer *cell,
   /* just a note, nothing else */
   GdkPixbuf *addon = NULL;
   if((celltype->type & 7) == 4)      // only note is set
-    addon = icon_get(ICON_MISC, 6);
+    addon = icon_get(CUSTOM_ICON_TYPE, 13);
   if((celltype->type & 7) == 5)      // only note and override are set
-    addon = icon_get(ICON_MISC, 1);
+    addon = icon_get(CUSTOM_ICON_TYPE, 11);
   if(celltype->type & 2)             // solved is set
-    addon = icon_get(ICON_MISC, 4);
+    addon = icon_get(CUSTOM_ICON_TYPE, 12);
   
   /* if override (and not found) is set */
   if(addon) {
