@@ -20,6 +20,16 @@
 #ifndef GCONF_H
 #define GCONF_H
 
+#define PROXY_KEY  "/system/http_proxy/"
+
+typedef struct proxy_s {
+  char *authentication_password, *authentication_user;
+  char *host;
+  char *ignore_hosts;
+  gint port;
+  gboolean use_authentication;
+} proxy_t;
+
 void gconf_save_state(appdata_t *appdata);
 void gconf_load_state(appdata_t *appdata);
 void gconf_save_closed_name(appdata_t *appdata, char *filename, char *name);
