@@ -24,34 +24,41 @@ struct icon_data {
   GdkPixbuf **data;
   int count;
 } icons[] = {
-  { NULL, CACHE_TYPE_MAX+1 },  /* ICON_CACHE_TYPE      */
-  { NULL, CACHE_TYPE_MAX+1 },  /* ICON_CACHE_TYPE_SEMI */
+  { NULL, CACHE_TYPE_MAX+4 },  /* ICON_CACHE_TYPE      */
+  { NULL, CACHE_TYPE_MAX+4 },  /* ICON_CACHE_TYPE_SEMI */
+  { NULL, CACHE_TYPE_MAX+4 },  /* ICON_CACHE_TYPE_1_5X */
+  { NULL, CACHE_TYPE_MAX+4 },  /* ICON_CACHE_TYPE_2X   */
   { NULL, CACHE_CONT_MAX+1 },  /* ICON_CACHE_SIZE      */
   { NULL, 9 },                 /* ICON_STARS           */
   { NULL, LOG_TYPE_MAX+1 },    /* ICON_LOG             */
   { NULL, 9 },                 /* ICON_HEADING         */
   { NULL, WPT_SYM_MAX+1 },     /* ICON_WPT             */
-  { NULL, 1 },                 /* ICON_TB              */
-  { NULL, 9 },                 /* ICON_MISC            */
+  { NULL, 2 },                 /* ICON_TB              */
+  { NULL, 6 },                 /* ICON_MISC            */
   { NULL, 3 },                 /* ICON_FILE            */
   { NULL, -1 }
 };
 
-/* ICON_CACHE_TYPE / ICON_CACHE_TYPE_SEMI */
+/* ICON_CACHE_TYPE / ICON_CACHE_TYPE_SEMI / ICON_CACHE_TYPE_2X */
 const char *cache_type_icon_name[] = {
   "traditional", "multi",      "mystery", "virtual", "webcam", "event",
-  "letterbox",   "earthcache", "wherigo", "megaevent", "cito"
+  "letterbox",   "earthcache", "wherigo", "megaevent", "cito",
+
+  /* special overlays */
+  "ovl_override", "ovl_found", "ovl_note", 
+
+  NULL
 };
 
 /* ICON_CACHE_SIZE */
 const char *cache_size_icon_name[] = {
   "regular", "small",      "micro", "other", "not_chosen", "large",
-  "virtual" 
+  "virtual", NULL
 };
 
 /* ICON_STARS      */
 const char *stars_icon_name[] = {
-  "1", "1_5", "2", "2_5", "3", "3_5", "4", "4_5", "5" 
+  "1", "1_5", "2", "2_5", "3", "3_5", "4", "4_5", "5", NULL
 };
 
 /* ICON_LOG        */
@@ -61,34 +68,35 @@ const char *log_icon_name[] = {
   "needsmaint", "coord_update",
   "traffic_cone",
   "traffic_cone", /* LOG_TYPE_NEEDS_ARCHIVED */
-  "traffic_cone",
+  "traffic_cone", 
+  NULL
 };  
 
 /* ICON_HEADING    */
 const char *heading_icon_name[] = {
-  "n", "ne", "e", "se", "s", "sw", "w", "nw", "none"
+  "n", "ne", "e", "se", "s", "sw", "w", "nw", "none", NULL
 };
 
 /* ICON_WPT        */
 const char *wpt_sym_icon_name[] = {
   "multistage", "parking", "final", "question",
-  "trailhead", "refpoint",
+  "trailhead", "refpoint", NULL
 };
 
 /* ICON_TB         */
 const char *tb_icon_name[] = {
-  "tb_coin"
+  "tb", "coin", NULL
 };
 
 /* ICON_MISC         */
 const char *misc_icon_name[] = {
-  "maemo-mapper-out", "override", "locked", "unlocked", "found", 
-  "maemo-mapper-in", "note", "delete", "paypal"
+  "maemo-mapper-out", "locked", "unlocked",
+  "maemo-mapper-in", "delete", "paypal", NULL
 };
 
 /* ICON_FILE         */
 const char *file_icon_name[] = {
-  "gc", "folder", "zip"
+  "gc", "folder", "zip", NULL
 };
 
 static void icons_load(int type, char *format, const char *names[]) {
@@ -102,79 +110,79 @@ static void icons_load(int type, char *format, const char *names[]) {
   icons[type].data = malloc(sizeof(GdkPixbuf *) * icons[type].count);
   
   for(i=0;i<icons[type].count;i++) {
-    if(names[i]) {
-      GError *error = NULL;
-      char filename[128];
-      strcpy(filename, ICONPATH);
-      snprintf(filename+strlen(filename),
-	      sizeof(filename)-strlen(filename), format, names[i], "png");
+    g_assert(names[i]);
+
+    GError *error = NULL;
+    char filename[128];
+    strcpy(filename, ICONPATH);
+    snprintf(filename+strlen(filename),
+	     sizeof(filename)-strlen(filename), format, names[i], "png");
+    icons[type].data[i] = gdk_pixbuf_new_from_file(filename, &error);
+    
+    if(error) {
+      error = NULL;
+      /* try again in local dir */
+      strcpy(filename, "./data/icons/");
+      snprintf(filename+strlen(filename), 
+	       sizeof(filename)-strlen(filename), format, names[i], "png");
       icons[type].data[i] = gdk_pixbuf_new_from_file(filename, &error);
-
+	
       if(error) {
-	/* try gif */
+	icons[type].data[i] = NULL;
+	g_warning("Could not load cache type icon %s: %s\n", 
+		      names[i], error->message);
+	g_error_free(error);
 	error = NULL;
-	strcpy(filename, ICONPATH);
-	snprintf(filename+strlen(filename),
-		 sizeof(filename)-strlen(filename), format, names[i], "gif");
-	icons[type].data[i] = gdk_pixbuf_new_from_file(filename, &error);
-
-	if(error) {
-	  error = NULL;
-	  /* try again in local dir */
-	  strcpy(filename, "./data/icons/");
-	  snprintf(filename+strlen(filename), 
-		   sizeof(filename)-strlen(filename), format, names[i], "png");
-	  icons[type].data[i] = gdk_pixbuf_new_from_file(filename, &error);
-	  
-	  if(error) {
-	    error = NULL;
-	    /* try gif */
-	    strcpy(filename, "./data/icons/");
-	    snprintf(filename+strlen(filename), 
-		   sizeof(filename)-strlen(filename), format, names[i], "gif");
-	    icons[type].data[i] = gdk_pixbuf_new_from_file(filename, &error);
-	    
-	    
-	    if(error) {
-	      icons[type].data[i] = NULL;
-	      g_warning("Could not load cache type icon %s: %s\n", 
-			names[i], error->message);
-	      g_error_free(error);
-	      error = NULL;
-	    }
-	  }
-	}   
-      }
-    } else
-      icons[type].data[i] = NULL;
+      }   
+    }
   }
+
+  g_assert(!names[i]);
 }
 
 void icons_init(void) {
 
   /* load cache type icons */
-  icons_load(ICON_CACHE_TYPE, "cache_type_%s.%s", cache_type_icon_name);
+  icons_load(ICON_CACHE_TYPE, "32x32/cache_type_%s.%s", cache_type_icon_name);
 
-  /* load cache type icons */
-  icons_load(ICON_CACHE_TYPE_SEMI, "cache_type_%s_semi.%s", cache_type_icon_name);
+  /* load semitransparent cache type icons */
+  icons_load(ICON_CACHE_TYPE_SEMI, "32x32/cache_type_%s_semi.%s", cache_type_icon_name);
+
+  /* load 150% sized cache type icons */
+  icons_load(ICON_CACHE_TYPE_1_5X, "48x48/cache_type_%s.%s", cache_type_icon_name);
+
+  /* load double sized cache type icons */
+  icons_load(ICON_CACHE_TYPE_2X, "64x64/cache_type_%s.%s", cache_type_icon_name);
 
   /* load cache container/size icons */
-  icons_load(ICON_CACHE_SIZE, "cache_size_%s.%s", cache_size_icon_name);
+#if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
+  icons_load(ICON_CACHE_SIZE, "45x12/cache_size_%s.%s", cache_size_icon_name);
+#else
+  icons_load(ICON_CACHE_SIZE, "90x24/cache_size_%s.%s", cache_size_icon_name);
+#endif
 
-  /* load cache difficulty/terrain icons */
-  icons_load(ICON_STARS, "stars%s.%s", stars_icon_name);
+  /* load cache difficulty/terrain/quality icons */
+#if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
+  icons_load(ICON_STARS, "12x12/stars%s.%s", stars_icon_name);
+#else
+  icons_load(ICON_STARS, "16x16/stars%s.%s", stars_icon_name);
+#endif
 
-  /* load cache difficulty/terrain icons */
-  icons_load(ICON_LOG, "log_icon_%s.%s", log_icon_name);
+  /* load cache log icons */
+  icons_load(ICON_LOG, "32x32/log_icon_%s.%s", log_icon_name);
 
   /* load icons to visualize heading */
-  icons_load(ICON_HEADING, "heading_%s.%s", heading_icon_name);
+#if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
+  icons_load(ICON_HEADING, "32x32/heading_%s.%s", heading_icon_name);
+#else
+  icons_load(ICON_HEADING, "48x48/heading_%s.%s", heading_icon_name);
+#endif
 
-  /* load icons to visualize heading */
-  icons_load(ICON_WPT, "wpt_%s.%s", wpt_sym_icon_name);
+  /* load waypoint icons */
+  icons_load(ICON_WPT, "32x32/wpt_%s.%s", wpt_sym_icon_name);
 
-  /* load travelbug icon */
-  icons_load(ICON_TB, "%s.%s", tb_icon_name);
+  /* load travelbug/coin icons */
+  icons_load(ICON_TB, "32x32/%s.%s", tb_icon_name);
 
   /* load misc icons */
   icons_load(ICON_MISC, "%s.%s", misc_icon_name);
