@@ -24,6 +24,8 @@
 enum { 
   ICON_CACHE_TYPE = 0,
   ICON_CACHE_TYPE_SEMI,
+  ICON_CACHE_TYPE_1_5X,
+  ICON_CACHE_TYPE_2X,
   ICON_CACHE_SIZE,
   ICON_STARS,
   ICON_LOG,
