@@ -33,6 +33,7 @@
 #include <hildon/hildon-banner.h>
 #if MAEMO_VERSION_MAJOR >= 5
 #include <hildon/hildon-note.h>
+#include <hildon/hildon-entry.h>
 #include <hildon/hildon-check-button.h>
 #endif
 #endif
@@ -689,7 +690,7 @@ static void gpxlist_set(GtkListStore *store, GtkTreeIter *iter, gpx_t *gpx) {
 		     GPXLIST_COL_OPEN, !gpx->closed,
 		     GPXLIST_COL_CACHES, gpx->closed?NULL:cnum,
 #ifdef USE_PANNABLE_AREA
-		     GPXLIST_COL_DELETE, icon_get(ICON_MISC, 7),
+		     GPXLIST_COL_DELETE, icon_get(ICON_MISC, 4),
 #endif
 		     GPXLIST_COL_DATA, gpx,
 		     -1);
@@ -1151,7 +1152,7 @@ cb_menu_about(GtkWidget *window, gpointer data) {
 
   GtkWidget *button = gtk_button_new();
   gtk_button_set_image(GTK_BUTTON(button), 
-		       icon_get_widget(ICON_MISC, 8));
+		       icon_get_widget(ICON_MISC, 5));
   gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
   g_signal_connect(button, "clicked", 
 		   G_CALLBACK(on_paypal_button_clicked), &context); 
@@ -1450,8 +1451,15 @@ cb_menu_search(GtkWidget *window, gpointer data) {
 
   gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(dialog)->vbox),
 			      gtk_label_new(_("Search for:")));
+#if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
+  context.entry = gtk_entry_new();
+#else
+  context.entry = hildon_entry_new(HILDON_SIZE_AUTO);
+#endif
+
   gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(dialog)->vbox),
-			      context.entry = gtk_entry_new());
+			      context.entry);
+
   if(appdata->search_str)
     gtk_entry_set_text(GTK_ENTRY(context.entry), appdata->search_str);
 
