@@ -155,12 +155,13 @@ static gboolean map_gps_update(gpointer data) {
 }
 
 static void map_draw_cache(GtkWidget *map, cache_t *cache, gboolean semi) {
-  GdkPixbuf *icon = icon_get(semi?ICON_CACHE_TYPE_SEMI:ICON_CACHE_TYPE, 
-			     cache->type);
+  int type = semi?ICON_CACHE_TYPE_SEMI:ICON_CACHE_TYPE;
+
+  GdkPixbuf *icon = icon_get(type, cache->type);
 
   /* check if there's also an overwritten coordinate */
   if(cache->notes && cache->notes->override) {
-    GdkPixbuf *over = icon_get(ICON_MISC, 1);
+    GdkPixbuf *over = icon_get(type, 11);
 
     osm_gps_map_add_image(OSM_GPS_MAP(map), 
 	  cache->notes->pos.lat, cache->notes->pos.lon, icon);
@@ -493,9 +494,11 @@ cairo_draw_pixbuf(cairo_t *cr, GdkPixbuf *buf, gint x, gint y) {
 }
 
 #ifndef BIG_BALLOONS
+#define ICON_SIZE  ICON_CACHE_TYPE
 #define LINE_SKIP  7
 #else
-#define LINE_SKIP  12
+#define ICON_SIZE  ICON_CACHE_TYPE_1_5X
+#define LINE_SKIP  7
 #endif
 
 static void 
@@ -523,11 +526,11 @@ balloon_cb(osm_gps_map_balloon_event_t *event, gpointer data) {
     gint x = event->data.draw.rect->x, y = event->data.draw.rect->y;
     
     /* draw the cache type icon ... */
-    GdkPixbuf *icon = icon_get(ICON_CACHE_TYPE, cache->type);
+    GdkPixbuf *icon = icon_get(ICON_SIZE, cache->type);
     cairo_draw_pixbuf(event->data.draw.cr, icon, x, y);
     
     if(cache->notes && cache->notes->override) {
-      GdkPixbuf *over = icon_get(ICON_MISC, 1);
+      GdkPixbuf *over = icon_get(ICON_SIZE, 11);
       cairo_draw_pixbuf(event->data.draw.cr, over, x, y);
     }
     
@@ -563,13 +566,17 @@ balloon_cb(osm_gps_map_balloon_event_t *event, gpointer data) {
     x = event->data.draw.rect->x;
     
     /* everything from here uses the same font */
-    cairo_select_font_face (event->data.draw.cr, "Sans", CAIRO_FONT_SLANT_NORMAL,
+    cairo_select_font_face (event->data.draw.cr, "Sans", 
+			    CAIRO_FONT_SLANT_NORMAL,
 			    CAIRO_FONT_WEIGHT_NORMAL);
+
 #ifndef BIG_BALLOONS
-    cairo_set_font_size (event->data.draw.cr, 14.0);
+#define FONT_SIZE 14.0
 #else
-    cairo_set_font_size (event->data.draw.cr, 22.0);
+#define FONT_SIZE 22.0
 #endif
+
+    cairo_set_font_size (event->data.draw.cr, FONT_SIZE);
     
     if(cache->name) {
       /* draw cache name */
@@ -586,42 +593,51 @@ balloon_cb(osm_gps_map_balloon_event_t *event, gpointer data) {
     }
     
     if(cache->terrain) {
+      int text_y = 0, icon_y = 0;
+
       /* draw cache rating */
       const char *terrain = "Terrain:"; 
       icon = icon_get(ICON_STARS, (int)(cache->terrain*2-2));
       cairo_text_extents (event->data.draw.cr, _(terrain), &extents);
-      y += (gdk_pixbuf_get_height(icon) + extents.height)/2;
-      
+
+      if(gdk_pixbuf_get_height(icon) > FONT_SIZE)
+	text_y = (gdk_pixbuf_get_height(icon) - FONT_SIZE)/2;
+      else
+	icon_y = (FONT_SIZE - gdk_pixbuf_get_height(icon))/2;
+
       /* draw "Terrain:" string */
-      cairo_move_to (event->data.draw.cr, x, y);
+      cairo_move_to (event->data.draw.cr, x, y - extents.y_bearing + text_y);
       cairo_set_source_rgba (event->data.draw.cr, 0, 0, 0, 1);
       cairo_show_text (event->data.draw.cr, _(terrain));
       cairo_stroke (event->data.draw.cr);
       x += extents.width + 2;
       
       /* draw terrain stars */
-      cairo_draw_pixbuf(event->data.draw.cr, icon, x, y - 
-			(gdk_pixbuf_get_height(icon) + extents.height)/2);
+      cairo_draw_pixbuf(event->data.draw.cr, icon, x, y + icon_y);
       
       x += gdk_pixbuf_get_width(icon) + LINE_SKIP;
-    y -= (gdk_pixbuf_get_height(icon) + extents.height)/2;
     }
     
     if(cache->difficulty) {
+      int text_y = 0, icon_y = 0;
+
       const char *difficulty = "Difficulty:"; 
+      icon = icon_get(ICON_STARS, (int)(cache->difficulty*2-2));
       cairo_text_extents (event->data.draw.cr, _(difficulty), &extents);
-      y += (gdk_pixbuf_get_height(icon) + extents.height)/2;
       
+      if(gdk_pixbuf_get_height(icon) > FONT_SIZE)
+	text_y = (gdk_pixbuf_get_height(icon) - FONT_SIZE)/2;
+      else
+	icon_y = (FONT_SIZE - gdk_pixbuf_get_height(icon))/2;
+
       /* draw "Difficulty:" string */
-      cairo_move_to (event->data.draw.cr, x, y);
+      cairo_move_to (event->data.draw.cr, x, y - extents.y_bearing + text_y);
       cairo_set_source_rgba (event->data.draw.cr, 0, 0, 0, 1);
       cairo_show_text (event->data.draw.cr, _(difficulty));
       cairo_stroke (event->data.draw.cr);
       x += extents.width + 2;
       
-      icon = icon_get(ICON_STARS, (int)(cache->difficulty*2-2));
-      cairo_draw_pixbuf(event->data.draw.cr, icon, x, y - 
-		      (gdk_pixbuf_get_height(icon) + extents.height)/2);
+      cairo_draw_pixbuf(event->data.draw.cr, icon, x, y + icon_y);
     }
   } else if(event->type == OSM_GPS_MAP_BALLOON_EVENT_TYPE_CLICK) {
     printf("click %s event at %d %d\n", 
