@@ -498,10 +498,10 @@ void mmpoi_export(appdata_t *appdata) {
       /* ---------------------- copy icons --------------------- */
       for(i=0;cache_type_icons[i][0];i++) {
 	char *src = malloc(strlen(ICONPATH)+strlen(cache_type_icons[i])+
-			   strlen("cache_type_.gif")+1);
-	sprintf(src, ICONPATH "cache_type_%s.gif", cache_type_icons[i]);
+			   strlen("cache_type_.png")+1);
+	sprintf(src, ICONPATH "cache_type_%s.png", cache_type_icons[i]);
 	if(!g_file_test(src, G_FILE_TEST_EXISTS)) 
-	  sprintf(src, "./icons/cache_type_%s.gif", cache_type_icons[i]);
+	  sprintf(src, "./icons/cache_type_%s.png", cache_type_icons[i]);
 	
 	if(g_file_test(src, G_FILE_TEST_EXISTS)) {
 	  char *dest = malloc(strlen(appdata->mmpoi_path)+
