@@ -27,6 +27,12 @@
 
 #include <math.h>
 
+#if defined(USE_MAEMO) && (MAEMO_VERSION_MAJOR >= 5)
+#include <hildon/hildon-note.h>
+#include <hildon/hildon-entry.h>
+#include <hildon/hildon-check-button.h>
+#endif
+
 #if !defined(LIBXML_TREE_ENABLED) || !defined(LIBXML_OUTPUT_ENABLED)
 #error "libxml doesn't support required tree or output"
 #endif
@@ -42,6 +48,33 @@ void gtk_text_buffer_set_rich_text_format(GtkTextBuffer *buffer, const gchar *);
 
 #define TAG_STATE  GTK_STATE_PRELIGHT
 
+static GtkWidget *check_button_new_with_label(char *label) {
+#if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
+  return gtk_check_button_new_with_label(label);
+#else
+  GtkWidget *cbut = 
+    hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH);
+  gtk_button_set_label(GTK_BUTTON(cbut), label);
+  return cbut;
+#endif
+}
+
+static void check_button_set_active(GtkWidget *button, gboolean active) {
+#if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), active);
+#else
+  hildon_check_button_set_active(HILDON_CHECK_BUTTON(button), active);
+#endif
+}
+
+static gboolean check_button_get_active(GtkWidget *button) {
+#if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
+  return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
+#else
+  return hildon_check_button_get_active(HILDON_CHECK_BUTTON(button));
+#endif
+}
+
 static notes_t *notes_load(appdata_t *appdata, cache_t *cache) {
   notes_t *notes = NULL;
   xmlDoc *doc = NULL;
@@ -254,11 +287,11 @@ static void notes_save(cache_context_t *context) {
     pos.lon = lon_get(context->notes.lonw);
 
     gboolean override = 
-      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(context->notes.overridew));
+      check_button_get_active(context->notes.overridew);
     gboolean found = 
-      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(context->notes.foundw));
+      check_button_get_active(context->notes.foundw);
     gboolean logged =
-      gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(context->notes.loggedw));
+      check_button_get_active(context->notes.loggedw);
 
     /* required accuracy is 1/60000 degree */
     if(((int)(pos.lat * 60000 + .5) != 
@@ -425,7 +458,7 @@ static void on_destroy_textview(GtkWidget *widget, gpointer data) {
 static void ftime_update(GtkWidget *widget, cache_context_t *context, 
 			 gboolean update) {
   /* check if it has been selected */
-  if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget))) {
+  if(check_button_get_active(GTK_TOGGLE_BUTTON(widget))) {
     printf("set active\n");
 
     if(update)
@@ -457,7 +490,7 @@ static void callback_modified(GtkWidget *widget, gpointer data ) {
     printf("was foundw\n");
 
     /* about to remove "found" flag -> ask for confirmation */
-    if(!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget))) {
+    if(!check_button_get_active(widget)) {
 #if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
       GtkWidget *dialog = gtk_message_dialog_new(
 		 GTK_WINDOW(context->appdata->window),
@@ -493,7 +526,7 @@ static void callback_modified(GtkWidget *widget, gpointer data ) {
     printf("was loggedw\n");
 
     /* about to remove "found" flag -> ask for confirmation */
-    if(!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget))) {
+    if(!check_button_get_active(widget)) {
 #if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
       GtkWidget *dialog = gtk_message_dialog_new(
 		 GTK_WINDOW(context->appdata->window),
@@ -583,27 +616,29 @@ GtkWidget *cache_notes(cache_context_t *context) {
   /* -------------- custom coordinate ---------------- */
 
   GtkWidget *table = gtk_table_new(2, 4, FALSE);
+#if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
   gtk_table_set_col_spacing(GTK_TABLE(table), 0, 16);
   gtk_table_set_col_spacing(GTK_TABLE(table), 2, 16);
+#endif
 
   gtk_table_attach_defaults(GTK_TABLE(table),
 		    gtk_label_new(_("New coordinate:")), 0, 1, 0, 1);  
-  context->notes.overridew = gtk_check_button_new_with_label(_("Override"));
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(context->notes.overridew), 
-			       cache->notes && cache->notes->override);
+  context->notes.overridew = check_button_new_with_label(_("Override"));
+  check_button_set_active(context->notes.overridew, 
+			  cache->notes && cache->notes->override);
   gtk_table_attach_defaults(GTK_TABLE(table),
 			    context->notes.overridew, 0, 1, 1, 2);  
 
   GtkWidget *hbox = gtk_hbox_new(FALSE, 2);
 
-  context->notes.foundw = gtk_check_button_new_with_label(_("Found"));
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(context->notes.foundw), 
-			       cache->notes && cache->notes->found);
+  context->notes.foundw = check_button_new_with_label(_("Found"));
+  check_button_set_active(context->notes.foundw, 
+			  cache->notes && cache->notes->found);
   gtk_box_pack_start_defaults(GTK_BOX(hbox), context->notes.foundw);
 
-  context->notes.loggedw = gtk_check_button_new_with_label(_("Logged"));
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(context->notes.loggedw), 
-			       cache->notes && cache->notes->logged);
+  context->notes.loggedw = check_button_new_with_label(_("Logged"));
+  check_button_set_active(context->notes.loggedw, 
+			  cache->notes && cache->notes->logged);
   gtk_box_pack_start_defaults(GTK_BOX(hbox), context->notes.loggedw);
   
   gtk_table_attach_defaults(GTK_TABLE(table), hbox, 3, 4, 0, 1);  
@@ -615,7 +650,7 @@ GtkWidget *cache_notes(cache_context_t *context) {
     gtk_widget_set_sensitive(context->notes.foundw, FALSE);
 
   context->notes.datew = gtk_label_new("");
-  gtk_misc_set_alignment(GTK_MISC(context->notes.datew), 0.0f, 0.5f);
+  gtk_misc_set_alignment(GTK_MISC(context->notes.datew), 0.5f, 0.5f);
   gtk_table_attach_defaults(GTK_TABLE(table),
 			    context->notes.datew, 3, 4, 1, 2);  
   ftime_update(context->notes.foundw, context, FALSE);
@@ -624,18 +659,22 @@ GtkWidget *cache_notes(cache_context_t *context) {
   if(cache->notes) pos = cache->notes->pos;
 
   gtk_table_attach_defaults(GTK_TABLE(table), 
-			    context->notes.latw = lat_entry_new(pos.lat), 2, 3, 0, 1);
+	    context->notes.latw = lat_entry_new(pos.lat), 2, 3, 0, 1);
   g_signal_connect(G_OBJECT(context->notes.latw), "focus-out-event", 
 		   G_CALLBACK(focus_out), context);
   
   gtk_table_attach_defaults(GTK_TABLE(table), 
-			    context->notes.lonw = lon_entry_new(pos.lon), 2, 3, 1, 2);
+	    context->notes.lonw = lon_entry_new(pos.lon), 2, 3, 1, 2);
   g_signal_connect(G_OBJECT(context->notes.lonw), "focus-out-event", 
 		   G_CALLBACK(focus_out), context);
 
+#if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_box_pack_start(GTK_BOX(hbox), table, FALSE, FALSE, 0);  
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);  
+#else
+  gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);  
+#endif
 
 #ifndef USE_PANNABLE_AREA
   GtkWidget *scrolled_window = gtk_scrolled_window_new(NULL, NULL);
@@ -715,8 +754,7 @@ void notes_free(notes_t *notes) {
 
 pos_t notes_get_pos(cache_context_t *context) {
   pos_t pos = context->cache->pos;
-  if(gtk_toggle_button_get_active(
-		 GTK_TOGGLE_BUTTON(context->notes.overridew))) {
+  if(check_button_get_active(context->notes.overridew)) {
     pos.lat = lat_get(context->notes.latw);
     pos.lon = lon_get(context->notes.lonw);
   }
@@ -725,9 +763,7 @@ pos_t notes_get_pos(cache_context_t *context) {
 
 gboolean notes_get_override(cache_context_t *context) {
   /* get override value */
-  return gtk_toggle_button_get_active(
-		      GTK_TOGGLE_BUTTON(context->notes.overridew));
-
+  return check_button_get_active(context->notes.overridew);
 }
 
 typedef struct {
